"""
__version__.py
~~~~~~~~~~~~~~

Information about the current version of the py-package-template package.
"""

__title__ = 'odinwolf'
__description__ = f'A wrapper for the {__title__} package.'
__version__ = '1.1.4'
__author__ = 'janus banus'
__author_email__ = 'janus.banus@gmail.com'
__license__ = 'Apache 2.0'
__url__ = 'https://youtube.com'
